@@ -18,15 +18,14 @@ def nc_vars(filename):
 
 def nc2xr(filename, vars=None, chunk_size=10):
 
-    with nc.Dataset(filename, "r") as rgrp:
-        attrs = rgrp.__dict__
+    nc_variables = nc_vars(filename)
 
-        tiles = list(rgrp.groups)
-        nc_variables = list(rgrp[tiles[0]].variables)
+    x_var = "x_distance" if "x_distance" in nc_variables else "x"
+    y_var = "y_distance" if "y_distance" in nc_variables else "y"
 
     if vars is not None:
         drop_variables = nc_variables.copy()
-        for v in vars + ["x", "y"]:
+        for v in vars + [x_var, y_var]:
             drop_variables.remove(v)
     else:
         drop_variables = []
@@ -50,6 +49,11 @@ def nc2xr(filename, vars=None, chunk_size=10):
 
     data = xr.merge(d)
 
+    if x_var == "x_distance":
+        data = data.rename({"x_distance": "x"})
+    if y_var == "y_distance":
+        data = data.rename({"y_distance": "y"})
+
     return data
 
 
